==> haskell-semirings-0.6-154-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-semirings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 semirings
version:              0.6
visibility:           public
id:                   semirings-0.6-HrLFL9KATFkDlEaoQRKJLH
key:                  semirings-0.6-HrLFL9KATFkDlEaoQRKJLH
license:              BSD-3-Clause
copyright:            Copyright (C) 2018 chessai
maintainer:           chessai <chessai1996@gmail.com>
author:               chessai
stability:            provisional
homepage:             http://github.com/chessai/semirings
synopsis:             two monoids as one, in holy haskimony
description:
    Haskellers are usually familiar with monoids and semigroups. A monoid has an appending operation `<>` (or `mappend`),
    and an identity element, `mempty`. A semigroup has an appending `<>` operation, but does not require a `mempty` element.

    A Semiring has two appending operations, `plus` and `times`, and two respective identity elements, `zero` and `one`.

    More formally, a Semiring R is a set equipped with two binary relations `+` and `*`, such that:

    (R,+) is a commutative monoid with identity element 0,

    (R,*) is a monoid with identity element 1,

    (*) left and right distributes over addition, and

    multiplication by '\''0'\'' annihilates R.

category:             Algebra, Data, Data Structures, Math, Maths, Mathematics
abi:                  ee8ed12801494ab04c2e3f93c85e5778
exposed:              True
exposed-modules:
    Data.Euclidean Data.Field Data.Semiring Data.Semiring.Generic
    Data.Semiring.Tropical Data.Star

import-dirs:          /usr/lib/ghc-9.2.8/site-local/semirings-0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/semirings-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semirings
hs-libraries:         HSsemirings-0.6-HrLFL9KATFkDlEaoQRKJLH
depends:
    base-4.16.4.0 base-compat-batteries-0.12.2-7m2pWGhUEYt4Tq7UyJt9y6
    containers-0.6.5.1 hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ

haddock-interfaces:   /usr/share/doc/haskell-semirings/html/semirings.haddock
haddock-html:         /usr/share/doc/haskell-semirings/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semirings-0.6-159-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-semirings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 semirings
version:              0.6
visibility:           public
id:                   semirings-0.6-1Mmgwd2bHEZ2ZWjOvPwut1
key:                  semirings-0.6-1Mmgwd2bHEZ2ZWjOvPwut1
license:              BSD-3-Clause
copyright:            Copyright (C) 2018 chessai
maintainer:           chessai <chessai1996@gmail.com>
author:               chessai
stability:            provisional
homepage:             http://github.com/chessai/semirings
synopsis:             two monoids as one, in holy haskimony
description:
    Haskellers are usually familiar with monoids and semigroups. A monoid has an appending operation `<>` (or `mappend`),
    and an identity element, `mempty`. A semigroup has an appending `<>` operation, but does not require a `mempty` element.

    A Semiring has two appending operations, `plus` and `times`, and two respective identity elements, `zero` and `one`.

    More formally, a Semiring R is a set equipped with two binary relations `+` and `*`, such that:

    (R,+) is a commutative monoid with identity element 0,

    (R,*) is a monoid with identity element 1,

    (*) left and right distributes over addition, and

    multiplication by '\''0'\'' annihilates R.

category:             Algebra, Data, Data Structures, Math, Maths, Mathematics
abi:                  3cfabcc7cddbef9cc48bfb402a20be84
exposed:              True
exposed-modules:
    Data.Euclidean Data.Field Data.Semiring Data.Semiring.Generic
    Data.Semiring.Tropical Data.Star

import-dirs:          /usr/lib/ghc-9.2.8/site-local/semirings-0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/semirings-0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semirings
hs-libraries:         HSsemirings-0.6-1Mmgwd2bHEZ2ZWjOvPwut1
depends:
    base-4.16.4.0 base-compat-batteries-0.12.2-5CHPed6R1NJ7UGbNvch4MS
    containers-0.6.5.1 hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:   /usr/share/doc/haskell-semirings/html/semirings.haddock
haddock-html:         /usr/share/doc/haskell-semirings/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
